@@ -316,16 +316,17 @@ sub replace {
     }
     if (! $driver->txn_active) {
         $driver->begin_work;
+        my $res;
         eval {
             $driver->remove(@_);
-            $driver->insert(@_);
+            $res = $driver->insert(@_);
         };
         if ($@) {
             $driver->rollback;
             Carp::croak("REPLACE transaction error $driver: $@");
         }
         $driver->commit;
-        return;
+        return $res;
     }
     $driver->remove(@_);
     $driver->insert(@_);
@@ -408,8 +409,8 @@ sub _insert_or_replace {
         $orig_obj->$id_col($id);
     }
 
-    $driver->end_query($sth);
     _close_sth($sth);
+    $driver->end_query($sth);
 
     $obj->call_trigger('post_save', $orig_obj);
     $obj->call_trigger('post_insert', $orig_obj);
